redbook_position: List of the number positions of the first 3 letters of the species name in
the redbook_tab
Description
The 'redbook_position' reports the
position (in term of number of rows) of the first three letters (triphthong)
for the plant names stored in the variable 'accepted_name' of the table
'redbook_tab'. This indexing system speeds up of the search on the
largest list using the package.
Usage
redbook_position
Arguments
Format
A data frame with 978 observations on the following 3 variables:
position
A character vector. The position of the first three letters of the species name in the redbook_tab.
triphthong
A character vector. The first three letters of the species name in the redbook_tab.
genus
A character vector. The corresponding genus name.
Details
Positions of Species Names in The Red Book of Endemic Plants of Peru
The redbook_position dataset provides the positions of the first three letters of each species name listed in the redbook_tab.